require 'spec_helper'

describe Net::Openvpn::Generators::Keys::Client do
  subject(:client) { Net::Openvpn::Generators::Keys::Client.new(name, props) }
  let(:directory)  { Net::Openvpn::Generators::Keys::Directory.new }
  let(:authority)  { Net::Openvpn::Generators::Keys::Authority }
  let(:name)       { "test" }
  let(:props)      { {} }

  before(:each) { setup_filesystem(:tmp) }
  after(:each)  { destroy_filesystem(:tmp) }

  it "should set the CN to the name" do
    expect(client.props[:key_cn]).to eq name
  end

  context "when a client has not been generated" do
    it "should not exist" do
      expect(client).to_not exist
    end

    it "should not be valid" do
      expect(client).to_not be_valid
    end
  end

  context "when the key directory has not been generated" do

    it "should raise an error" do
      expect { client.generate }.to raise_error(
        Net::Openvpn::Errors::KeyGeneration,
        "Key directory has not been generated yet"
      )
    end

  end

  context "when the key directory has been generated" do
    before(:each) { directory.generate }

    context "and the authority has not been generated" do
      before(:each) { expect(authority).to_not exist }

      it "should raise an error" do
        expect { client.generate }.to raise_error(
          Net::Openvpn::Errors::KeyGeneration,
          "Certificate Authority has not been created"
        )
      end
    end

    context "and the authority has been generated" do
      before(:each) do
        authority.new.generate
        expect(authority).to exist
      end

      context "and the client has not been generated" do
        it "should not exist" do
          expect(client).to_not exist
        end

        it "should not be valid" do
          expect(client).to_not be_valid
        end
      end

      context "and the client has been generated" do
        before(:each) { client.generate }

        it "should exist" do
          expect(client).to exist
        end

        it "should be valid" do
          expect(client).to be_valid
        end

        it "should allow revocation" do
          expect(client.revoke!).to be_true
          expect(client).to_not be_valid
        end

        context "and the common name was changed" do
          let(:name) { "test2" }

          it "should not be valid" do
            puts client.props
            expect(client).to_not be_valid
          end
        end
      end
    end

  end
end